import { Instance as FlatpickrInstance } from 'flatpickr/dist/types/instance';
import { Column, ColumnFilter, Filter, FilterArguments, FilterCallback, FlatpickrOption, GridOption, Locale, OperatorDetail, SlickGrid } from '../interfaces/index';
import { OperatorString, OperatorType, SearchTerm } from '../enums/index';
import { TranslaterService } from '../services/translater.service';
import { BindingEventService } from '../services/bindingEvent.service';
export declare class CompoundDateFilter implements Filter {
    protected readonly translaterService: TranslaterService;
    protected _bindEventService: BindingEventService;
    protected _clearFilterTriggered: boolean;
    protected _currentDate: Date | undefined;
    protected _currentValue?: string;
    protected _flatpickrOptions: FlatpickrOption;
    protected _filterElm: HTMLDivElement;
    protected _filterDivInputElm: HTMLDivElement;
    protected _operator: OperatorType | OperatorString;
    protected _selectOperatorElm: HTMLSelectElement;
    protected _shouldTriggerQuery: boolean;
    flatInstance: FlatpickrInstance;
    grid: SlickGrid;
    searchTerms: SearchTerm[];
    columnDef: Column;
    callback: FilterCallback;
    filterContainerElm: HTMLDivElement;
    constructor(translaterService: TranslaterService);
    /** Getter for the Grid Options pulled through the Grid Object */
    protected get gridOptions(): GridOption;
    /** Getter for the Filter Operator */
    get columnFilter(): ColumnFilter;
    /** Getter for the Current Dates selected */
    get currentDate(): Date | undefined;
    /** Getter to know what would be the default operator when none is specified */
    get defaultOperator(): OperatorType | OperatorString;
    /** Getter for the Flatpickr Options */
    get flatpickrOptions(): FlatpickrOption;
    /** Getter for the single Locale texts provided by the user in main file or else use default English locales via the Constants */
    get locales(): Locale;
    /** Getter for the Filter Operator */
    get operator(): OperatorType | OperatorString;
    /** Setter for the Filter Operator */
    set operator(op: OperatorType | OperatorString);
    /**
     * Initialize the Filter
     */
    init(args: FilterArguments): void;
    /**
     * Clear the filter value
     */
    clear(shouldTriggerQuery?: boolean): void;
    /**
     * destroy the filter
     */
    destroy(): void;
    hide(): void;
    show(): void;
    getValues(): Date | undefined;
    /** Set value(s) in the DOM element, we can optionally pass an operator and/or trigger a change event */
    setValues(values: SearchTerm | SearchTerm[], operator?: OperatorType | OperatorString): void;
    protected buildDatePickerInput(searchTerm?: SearchTerm): HTMLDivElement;
    /** Get the available operator option values to populate the operator select dropdown list */
    protected getOperatorOptionValues(): OperatorDetail[];
    /** Get Locale, Translated or a Default Text if first two aren't detected */
    protected getOutputText(translationKey: string, localeText: string, defaultText: string): string;
    /**
     * Create the DOM element
     */
    protected createDomElement(searchTerm?: SearchTerm): HTMLDivElement;
    protected onTriggerEvent(e: Event | undefined): void;
}
