import { Column, ColumnFilter, Filter, FilterArguments, FilterCallback, GridOption, Locale, OperatorDetail, SlickGrid } from '../interfaces/index';
import { OperatorString, OperatorType, SearchTerm } from '../enums/index';
import { BindingEventService } from '../services/bindingEvent.service';
import { TranslaterService } from '../services/translater.service';
export declare class CompoundSliderFilter implements Filter {
    protected readonly translaterService: TranslaterService;
    protected _bindEventService: BindingEventService;
    protected _clearFilterTriggered: boolean;
    protected _currentValue?: number;
    protected _shouldTriggerQuery: boolean;
    protected _elementRangeInputId: string;
    protected _elementRangeOutputId: string;
    protected _operator?: OperatorType | OperatorString;
    protected containerInputGroupElm?: HTMLDivElement;
    protected divContainerFilterElm?: HTMLDivElement;
    protected filterElm: HTMLDivElement;
    protected filterInputElm: HTMLInputElement;
    protected filterNumberElm?: HTMLSpanElement;
    protected selectOperatorElm: HTMLSelectElement;
    grid: SlickGrid;
    searchTerms: SearchTerm[];
    columnDef: Column;
    callback: FilterCallback;
    filterContainerElm: HTMLDivElement;
    constructor(translaterService: TranslaterService);
    /** Getter for the Filter Operator */
    get columnFilter(): ColumnFilter;
    /** Getter to know what would be the default operator when none is specified */
    get defaultOperator(): OperatorType | OperatorString;
    /** Getter for the Filter Generic Params */
    protected get filterParams(): any;
    /** Getter for the `filter` properties */
    protected get filterProperties(): ColumnFilter;
    /** Getter for the Grid Options pulled through the Grid Object */
    protected get gridOptions(): GridOption;
    /** Getter for the single Locale texts provided by the user in main file or else use default English locales via the Constants */
    get locales(): Locale;
    /** Getter for the Filter Operator */
    get operator(): OperatorType | OperatorString;
    /** Setter for the Filter Operator */
    set operator(op: OperatorType | OperatorString);
    /**
     * Initialize the Filter
     */
    init(args: FilterArguments): void;
    /**
     * Clear the filter value
     */
    clear(shouldTriggerQuery?: boolean): void;
    /**
     * destroy the filter
     */
    destroy(): void;
    /**
     * Get selected value retrieved from the slider element
     * @params selected items
     */
    getValues(): number | undefined;
    /** Set value(s) on the DOM element */
    setValues(values: SearchTerm | SearchTerm[], operator?: OperatorType | OperatorString): void;
    /** Get the available operator option values to populate the operator select dropdown list */
    protected getOperatorOptionValues(): OperatorDetail[];
    /** Get Locale, Translated or a Default Text if first two aren't detected */
    protected getOutputText(translationKey: string, localeText: string, defaultText: string): string;
    /**
     * Create the DOM element
     */
    protected createDomElement(searchTerm?: SearchTerm): HTMLDivElement;
    protected handleInputChange(event: Event): void;
    protected onTriggerEvent(e: Event | undefined): void;
}
