"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getAssociatedDateSortComparer = exports.compareDates = void 0;
const fieldType_enum_1 = require("../enums/fieldType.enum");
const utilities_1 = require("../services/utilities");
const moment_ = require("moment-mini");
const moment = moment_['default'] || moment_; // patch to fix rollup "moment has no default export" issue, document here https://github.com/rollup/rollup/issues/670
function compareDates(value1, value2, sortDirection, sortColumn, gridOptions, format, strict) {
    var _a, _b;
    let diff = 0;
    const checkForUndefinedValues = (_b = (_a = sortColumn === null || sortColumn === void 0 ? void 0 : sortColumn.valueCouldBeUndefined) !== null && _a !== void 0 ? _a : gridOptions === null || gridOptions === void 0 ? void 0 : gridOptions.cellValueCouldBeUndefined) !== null && _b !== void 0 ? _b : false;
    const date1 = moment(value1, format, strict);
    const date2 = moment(value2, format, strict);
    if (value1 === null || value1 === '' || (checkForUndefinedValues && value1 === undefined) || !date1.isValid()) {
        diff = -1;
    }
    else if (value2 === null || value2 === '' || (checkForUndefinedValues && value2 === undefined) || !date2.isValid()) {
        diff = 1;
    }
    else {
        diff = date1.valueOf() < date2.valueOf() ? -1 : 1;
    }
    return sortDirection * diff;
}
exports.compareDates = compareDates;
/** From a FieldType, return the associated Date SortComparer */
function getAssociatedDateSortComparer(fieldType) {
    const FORMAT = (fieldType === fieldType_enum_1.FieldType.date) ? moment.ISO_8601 : (0, utilities_1.mapMomentDateFormatWithFieldType)(fieldType);
    return ((value1, value2, sortDirection, sortColumn, gridOptions) => {
        if (FORMAT === moment.ISO_8601) {
            return compareDates(value1, value2, sortDirection, sortColumn, gridOptions, FORMAT, false);
        }
        return compareDates(value1, value2, sortDirection, sortColumn, gridOptions, FORMAT, true);
    });
}
exports.getAssociatedDateSortComparer = getAssociatedDateSortComparer;
//# sourceMappingURL=dateUtilities.js.map